// INPUT:
//
// X:      Pointer to gmfsetup struct, containing work 
//         arrays and control parameters.
// raw:    Pointer to the beginning of raw split-complex
//         32+32-bit float data.
// ngates: Number of range gates to handle.
// gate0:  Index of the first location to be used from
//         the X.shifts[] and X.acc[] arrays. 
//         Ngates locations are used.
//
// OUTPUT:
//
// gmf2:   Array of vectors, one vector per range gate. 
//         Each vector is a velocity 
//         slice v-->(MF(r, v, acc(r)))^2

void gmf ( ... )
{

     // Initialize pointers to the FFT input vectors
     // FFTIN(r,:), for the ngates range gates. These record
     // the current position in each vector.
  
    for ( gate = 0; gate < ngates; gate++ ) 
    {
        fftinpos[gate].realp = ...
        fftinpos[gate].imagp = ...
    }        

    // The next loop produces the FFT input vectors
    // FFTIN(r,:).  We handle data IPP per IPP,
    // growing the FFTIN(r,:) vectors "in parallel".
    // Each vector is of the form 
    // FFTIN(r,:) = TX .* RX .* exp ( -i * acc(r) * n^2 ),
    // where TX is the IPP's transmission, shifted
    // by shift(r).

    for ( ipp = 0; ipp < nipp; ipp++ )	// IPP LOOP //
    {
        // Point to transmission samples of this IPP.

        tx.realp = ...
        tx.imagp = ...
 
        for ( gate = 0; gate < ngates; gate++ )// GATE LOOP
        {
            // Fill in zeros in FFTIN, in front of
            // this IPP's TX .* RX

            memset ( ... ); 

            // Point to the reception samples starting at
            // gate, in this IPP. Note that we actually
            // can cross the IPP boundary here, and use
            // data from the second and even third
            // reception window.

            rx.realp = tx.realp + shift[gate];
            rx.imagp = tx.imagp + shift[gate];

            // Multiply the reception samples by the
            // shifted TX. Matlab code: 
            //   FFTIN(gate,pos1:pos2) =
            //      conj(TX) .* RX  
            // We use a vectorized routine
            // from Apple's vDSP library.

            zvmul ( &tx,, &rx,, &fftinpos[gate],, tlen,,);

            // Perform acceleration correction, using 
            // pre-computed, range-specific acceleration
            // value. Eq uivalent Matlab code: 
            //   FFTIN(gate,pos1:pos2) = 
            //     FFTIN(gate,pos1:pos2) .*
            //         exp(-i*acc(gate)*(n1:n2).^2)

            acc_correct_gmf ( &fftinpos[gate], 
                                tlen, accel[gate], 
                                   txon[ipp] + shift[gate]);

            // If this is the last IPP, zero-padd
            // FFTIN(gate,:) to length fftlen
            
            if ( ipp == nipp - 1 )            
                memset ( ... )
                
        }// END OF GATE LOOP
    }// END OF IPP LOOP

    // We now have the FFTIN(1:ngates,1:nfftin) matrix ready
    
    for ( gate = 0; gate < ngates; gate++ )
    {
        // Perform FFT
        // Matlab code:
        //    FFTIN(gate,:) = fft ( FFTIN(gate,:) )
        // Use optimized routine from Apple's vDSP library.	

        fft_zip ( fftsetup, &fftin[gate], stride,
                     log2n, FFT_FORWARD );

        // Take gmflen points around the zero frequency, and
        // compute squared magnitude.
        // Matlab code:
        //    GMF2(gate,1:gmflen) = 
        //        ( abs(FFTIN(gate,...) ) .^ 2 

        fft2gmf ( fftin[gate], fftlen, gmflen, gmf2[gate] );
    }

    return;
}
