function sd_accerrf

% ACCERRF
%
%   Loss of coherence due to "acceleration error".
%
%   Evaluate and plot I = int_0^1{dx exp[i 2pi (a/lambda)Tc^2] x^2}  
%   and A = sqrt(Tc) * I;        
%
%   29-Jun-2004 Jm


set(0,'DefaultAxesFontSize',14)

%func1
func2
%func4
%func5b
%func6
%func10


function func1

a = linspace(0,50,500);
Tc = [0.10 0.15 0.30 0.50 ];
lambda = 0.32;


for k=1:length(Tc)
    x = 2*pi*(a/lambda) * (Tc(k)^2);
    I{k} = sd_aerf(x);
    A{k} = sqrt(Tc(k)) .* I{k};
    T{k} = sprintf('%1.2f s',Tc(k));
end    

Color = {[1,0,0]; [0.7,0,0.3];[0.3,0,0.7]; [0,0,1]};

getfig(mfilename)    
    for k=1:length(Tc)
        H(k)=plot(a,I{k}); set(H(k),'color',Color{k});
        hold on
    end        
    ylabel('A_{est} / A')
    xlabel('\Deltaa_r (m/s^2)')
    hold off       
    set(gca,'ylim',[0 1.05]);


legend(T); legend boxoff;


function func2
%-----------------------------------------------------------
%   AF for CW as function of a - a0.
%

a = linspace(0,10,100);
Tc = [0.10 0.15 0.30 0.50 ];
lambda = 3/9.29;

AF0 = sd_aerf(0) * sqrt(0.1);

for k=1:length(Tc)
    x = 2*pi*(a/lambda) * (Tc(k)^2);
    I{k} = sd_aerf(x);
    A{k} = sqrt(Tc(k)) .* I{k} / AF0;
    T{k} = sprintf('%1.2f s',Tc(k));
end    
%Color = {[1,0,0]; [0.7,0.0,0.3];[0.5,0.3,0.7]; [0,0,1]};
Color = {[0,0,1];[0.3,0.3,0.3]; [1,0,0]; [0.0,0.0,0.0]; };

getfig(mfilename)    
    for k=1:length(Tc)
        c = A{k}(1);
        H(k)=plot(a,A{k}/c); set(H(k),'color',Color{k});
        hold on
        if k == 2, set (H(k),'linestyle','-'); end
        if k == 3, set (H(k),'linewidth',1.5); end
        if k == 4, set (H(k),'linestyle','--'); end
    end        
%    ylabel('AF / AF_0')
    ylabel('AF')
    xlabel('a-a_0 (m s^{-2})')
    hold off       
    set(gca,'ylim',[0 1.05]);
    jax

legend(T); %legend boxoff;


function func3

Tc = linspace(0,0.5,100);
a = 5;
lambda = 0.32;

x = 2*pi*(a/lambda) * (Tc.^2);

I = sd_aerf(x);
A = sqrt(Tc) .* I;


getfig(mfilename)    
subplot(2,1,1)
    plot(Tc,I,'-');
    ylabel('G/G(0)')
    xlabel('T_c (s)')
subplot(2,1,2)
    plot(Tc,A,'-');
    ylabel('G')
    xlabel('T_c (s)')
       

function func4
%--------------------------------------------------------------
%   AF as function a - a0, for various Tc.
%
%-------------------------------------------------------------- 
expname = 'tau2';

a = linspace(0,15,200);
Tc = [0.10 0.15 0.20 0.30 ];
lambda = 3/9.29;


AF_B = sd_a_ambi(0,0.1,'tau2');

for k=1:length(Tc)
    Tc(k)    
    [I,TC(k)] = sd_a_ambi(a,Tc(k),expname);
    A{k} = I/AF_B;
    T{k} = sprintf('%1.2f s',TC(k));
end    

Color = {[1,0,0]; [0.7,0.0,0.3];[0.5,0.3,0.7]; [0,0,1]};

getfig([mfilename ' func4']); clf    
    for k=1:length(Tc)
        H(k)=plot(a,A{k});  
                set(H(k),'color',Color{k});
                set(H(k),'linewidth',2.0);
        hold on
    end        
    ylabel('AF / AF0')
    xlabel('a - a_0 (m/s^2)')
    set(gca,'layer','top');
    hold off       
    set(gca,'ylim',[0 2.00]);
    jax(0.8)
    legend(T); legend boxoff;



function func5
%--------------------------------------------------------------
%   AF as function of v - v0, for various a and a fixed Tc.
%
%-------------------------------------------------------------- 

expname = 'tau2';

v = -9:0.05:69;
a = [0 5 10 20 ];
Tc = 0.1;

AF0 = sd_va_ambi (0, 0, 0.1,expname);
N = 3

for k = 1:N
    [I,TC(k)] = sd_va_ambi (v,a(k),Tc,expname);
    A{k} = I/AF0;

    if k > 1
        K = find( A{k} < 0.2 );
        A{k}(K) = NaN;
    end

    Txt{k} = sprintf('a-a0 = %1.0f m/s^2',a(k));

end

Color = {[1,0,0]; [0.7,0.0,0.3];[0.5,0.3,0.7]; [0,0,1]};
Color = {0.5*[1,1,1]; [1.0,0.0,1.0];[0.0,0.0,1.0]};

getfig([mfilename ' func5']) ; clf   
    for k = 1:N
        H(k) = plot(v,A{k}); set (H(k),'color',Color{k});
        hold on
    end
    hold off        
    set(gca,'ylim',[0 2.5])
    xlabel('v - v_0 (m/s)')
    ylabel('AF / AF0')
    set(gca,'layer','top');
    jax(0.4);

    legend (H,Txt,0); legend boxoff;

function func5b
%--------------------------------------------------------------
%   AF as function of v, for various a and fixed v0 and Tc.
%
%-------------------------------------------------------------- 

expname = 'tau2';

v0 = 1008;
v = 970:0.05:1020;
a = [0 10 30 ];
Tc = 0.1;

AF0 = sd_va_ambi (0, 0, 0.1,expname);
N = 3


for k = 1:N
    [I,TC(k)] = sd_va_ambi (v-v0,a(k),Tc,expname);
    A{k} = I/AF0;

    if k > 1
        K = find( A{k} < 0.25 );
        A{k}(K) = NaN;
    end

    Txt{k} = sprintf('a-a0 = %1.0f m/s^2',a(k));

end

Color = {[1,0,0]; [0.7,0.0,0.3];[0.5,0.3,0.7]; [0,0,1]};
Color = {0.7*[1,1,1]; [1.0,0.0,1.0];[0.0,0.0,1.0]};

getfig([mfilename ' func5b']) ; clf   
    hh=area(v,A{1}); set(hh,'facecolor',Color{1},'edgecolor',Color{1});
    hold on
    for k = 1:N
        H(k) = plot(v,A{k}); 
                set (H(k),'color',Color{k});
                set (H(k),'linewidth',2);
                
    end
    hold off        
    set(gca,'ylim',[0 1.5])
    xlabel('v (m/s)')
    ylabel('AF / AF0')
    set(gca,'layer','top');
    jax(0.75*0.5);

    legend (H,Txt,0); legend boxoff;
    
function func6
%--------------------------------------------------------------
%   FAF as function of v, for various a and a fixed v0 and Tc.
%
%-------------------------------------------------------------- 

expname = 'tau2';

v = 850:0.2:1250;
v0 = 1106;
a = [0 5 10 20 ];
Tc = 0.3;

AF0 = sd_va_ambi (0, 0, 0.1,expname);
N = 3

for k = 1:N
    [I,TC(k)] = sd_va_fambi (v,v0,a(k),Tc,expname);
    A{k} = I/AF0;

    if k > 1
        K = find( A{k} < 0.1 );
        A{k}(K) = NaN;
    end

    Txt{k} = sprintf('a-a0 = %1.0f m/s^2',a(k));

end

%Color = {[1,0,0]; [0.7,0.0,0.3];[0.5,0.3,0.7]; [0,0,1]};
Color = {0.5*[1,1,1]; [1.0,0.0,1.0];[0.0,0.0,1.0]};

getfig([mfilename ' func6']) ; clf   
    for k = 1:N
        H(k) = plot(v,A{k}); set (H(k),'color',Color{k});
        hold on
    end
    hold off        
    set(gca,'ylim',[0 2.0])
    xlabel('v (m/s)')
    ylabel('FAF / AF0')
    set(gca,'layer','top');
    jax(0.6);

    legend (H,Txt,0); legend boxoff;

%%%%%%%%%%%%%%%%%%%%%

    
function func10
%----------------------------------------------------------------------
% The two "components" of FAF(v)
%
%   FAF = abs [sum_n^L {exp i (w0-w)n} ] * [sum_m^M {exp i(w0*P - wL)}] 
%
%       --> diric (w0-w,L) * diric ( w0*P-wL, M )
%

Tc = 0.1;
v0 = 1008;
v = 500:.1:1500;

%v0 = 1317-32
%v = 850:.1:1750;

expname = 'tau2';
tau = 2e-6;
lambda = 3/9.29;

[P,L,M] = sd_pulsetrain (expname,tau,Tc)
Tc_actual = M*P*tau;

W = 2*pi*(v/(lambda/2))*tau;
W0 = 2*pi*(v0/(lambda/2))*tau;

D1 = abs(diric (W0-W,L));
D2 = abs(diric (W0*P-L*W,M));
FAF = D1 .* D2;

[maxFAF,k] = max(FAF)
vmax = v(k)
vmax_est = sd_v02vest ( P*tau,L*tau,v0,lambda)

getfig([mfilename ' func10']); clf;
%h = plot(v,D1,'b',v,D2,'b',v,FAF,'r'); set(h(2),'color',0.5*[1 1 1]);
box on
hold on

h = area(v,D1); 
set(h,'facecolor',[0.8]*[1,1,1],'edgecolor',0.8*[1,1,1])

h = plot(v,D2); set(h,'color',0.3*[1 1 1],'linewidth',1.5);

h = area(v,FAF); 
set(h,'facecolor','b','edgecolor','b')

title('REAL CASE (v0 = 1285 m/s, v\_est = 1318 m/s, loss = 2%)');

xlabel('v (m/s)')
ylabel('FAF')
jax(0.4)
set(gca,'layer','top')
set(gca,'ylim',[0,1.1])
set(gca,'xlim',[v(1),v(end)])
hold off    



     
function func11
%----------------------------------------------------------------------
% The two "components" of v->AF(v)
%
%   FAF = abs [sum_n^L {exp i (w0-w)n} ] * [sum_m^M {exp i(w0*P - wP)}] 
%
%       --> diric (w0-w,L) .* diric ( (w0-w)*P, M )
%

Tc = 0.1;
v0 = 1000.3;
v = 500:0.1:1500;

v0 = 1000.3;

expname = 'tau2';
tau = 2e-6;
lambda = 3/9.29;

[P,L,M] = sd_pulsetrain (expname,tau,Tc);
Tc_actual = M*P*tau;

W = 2*pi*(v/(lambda/2))*tau;
W0 = 2*pi*(v0/(lambda/2))*tau;

D1 = abs(diric (W0-W,L));
D2 = abs(diric (W0*P-P*W,M));
AF = D1 .* D2;

%[maxAF,k] = max(AF);
%vmax = v(k)
%vmax_est = sd_v02vest ( P*tau,L*tau,v0,lambda)

getfig([mfilename ' func11']); clf;
%h = plot(v,D1,'b',v,D2,'b',v,AF,'r'); set(h(2),'color',0.5*[1 1 1]);
%hold on
h = area(v,AF); 
set(h,'facecolor','r','edgecolor','r')
xlabel('v (m/s)')
ylabel('AF')
jax(0.4)
set(gca,'layer','top')
set(gca,'ylim',[0,1.1])
set(gca,'xlim',[v(1),v(end)])
hold off    


function jax (yscale);
    if nargin == 0
        yscale = 0.8;
    end        
    v = get(gca,'pos');
    set(gca,'pos',[v(1),v(2)+0.1,v(3),yscale*v(4)]);

